@@ -1,6 +1,6 @@
 // arith-tex.h -- arithmetic on textured values
 //
-//  Copyright (C) 2008  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2008, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __ARITH_TEX_H__
-#define __ARITH_TEX_H__
+#ifndef SNOGRAY_ARITH_TEX_H
+#define SNOGRAY_ARITH_TEX_H
 
 #include "tex.h"
 
@@ -62,4 +62,4 @@ public:
 #include "arith-tex.tcc"
 
 
-#endif // __ARITH_TEX_H__
+#endif // SNOGRAY_ARITH_TEX_H
