@@ -18,25 +18,34 @@
 using namespace snogray;
 
 
-// Transform this bounding-box by XFORM, ensuring that the result is
-// still axis-aligned.
+// Return this bounding-box transformed by XFORM, ensuring that the
+// result is still axis-aligned.
 //
 BBox
-BBox::operator* (const XformBase<dist_t> &xform) const
+BBox::transformed (const XformBase<dist_t> &xform) const
 {
-  BBox xformed_bbox (min * xform);
+  BBox xformed_bbox (xform (min));
 
-  xformed_bbox += Pos (min.x, min.y, max.z) * xform;
-  xformed_bbox += Pos (min.x, max.y, min.z) * xform;
-  xformed_bbox += Pos (min.x, max.y, max.z) * xform;
-  xformed_bbox += Pos (max.x, min.y, min.z) * xform;
-  xformed_bbox += Pos (max.x, min.y, max.z) * xform;
-  xformed_bbox += Pos (max.x, max.y, min.z) * xform;
+  xformed_bbox += xform (Pos (min.x, min.y, max.z));
+  xformed_bbox += xform (Pos (min.x, max.y, min.z));
+  xformed_bbox += xform (Pos (min.x, max.y, max.z));
+  xformed_bbox += xform (Pos (max.x, min.y, min.z));
+  xformed_bbox += xform (Pos (max.x, min.y, max.z));
+  xformed_bbox += xform (Pos (max.x, max.y, min.z));
 
-  xformed_bbox += max * xform;
+  xformed_bbox += xform (max);
 
   return xformed_bbox;
 }
 
+// Transform this bounding-box by XFORM, ensuring that the result is
+// still axis-aligned.
+//
+void
+BBox::transform (const XformBase<dist_t> &xform)
+{
+  *this = transformed (xform);
+}
+
 
 // arch-tag: fa0045f7-1646-422c-86ec-6375b51ae950
