@@ -10,6 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
+#include <ostream>
+
 #include "nice-io.h"
 
 #include "color-io.h"
@@ -19,10 +21,10 @@ snogray::operator<< (std::ostream &os, const Color &col)
 {
   for (unsigned c = 0; c < Color::NUM_COMPONENTS; c++)
     {
-      os << ((c == 0) ? "color<" : ", ");
+      os << ((c == 0) ? "color{" : ", ");
       output_nicely (os, col[c]);
     }
-  os << '>';
+  os << '}';
 
   return os;
 }
