@@ -1,6 +1,6 @@
 // grey-tex.h -- float-to-color conversion texture
 //
-//  Copyright (C) 2008  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2008, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __GREY_TEX_H__
-#define __GREY_TEX_H__
+#ifndef SNOGRAY_GREY_TEX_H
+#define SNOGRAY_GREY_TEX_H
 
 #include "tex.h"
 #include "color.h"
@@ -42,4 +42,4 @@ public:
 }
 
 
-#endif // __GREY_TEX_H__
+#endif // SNOGRAY_GREY_TEX_H
