@@ -1,6 +1,6 @@
 // image-filter.cc -- Filters for image output
 //
-//  Copyright (C) 2006, 2007, 2010, 2011  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2006, 2007, 2010-2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -28,34 +28,20 @@ using namespace snogray;
 ImageFilter *
 ImageFilter::make (const ValTable &params)
 {
-  std::string filter_type = params.get_string ("filter", "mitchell");
-
-  ValTable all_filter_params
-    = params.filter_by_prefix ("filter.");
-  ValTable filter_params
-    = all_filter_params.filter_by_prefix (filter_type + ".");
-
-  // For "generic" parameters, which apply to every filter type,
-  // default to a parameter entry without the filter-type in the name,
-  // if no more specific entry exists for that parameter.
-  //
-  filter_params.default_from ("x-width,xw,width,w", all_filter_params);
-  filter_params.default_from ("y-width,yw,width,w", all_filter_params);
-  filter_params.default_from ("x-width-scale", all_filter_params);
-  filter_params.default_from ("y-width-scale", all_filter_params);
+  std::string filter_type = params.get_string ("type", "mitchell");
 
   // Create the filter.
   //
   if (filter_type == "none")
     return 0;
   else if (filter_type == "mitchell")
-    return new ImageMitchellFilt (filter_params);
+    return new ImageMitchellFilt (params);
   else if (filter_type == "gauss")
-    return new ImageGaussFilt (filter_params);
+    return new ImageGaussFilt (params);
   else if (filter_type == "triangle")
-    return new ImageTriangleFilt (filter_params);
+    return new ImageTriangleFilt (params);
   else if (filter_type == "box")
-    return new ImageBoxFilt (filter_params);
+    return new ImageBoxFilt (params);
   else
     throw std::runtime_error (filter_type + ": unknown output filter type");
 }
