@@ -1,6 +1,6 @@
 // local-primitive.h -- Transformed primitive
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __LOCAL_PRIMITIVE_H__
-#define __LOCAL_PRIMITIVE_H__
+#ifndef SNOGRAY_LOCAL_PRIMITIVE_H
+#define SNOGRAY_LOCAL_PRIMITIVE_H
 
 
 #include "material.h"
@@ -47,4 +47,4 @@ public:
 }
 
 
-#endif // __LOCAL_PRIMITIVE_H__
+#endif // SNOGRAY_LOCAL_PRIMITIVE_H
