@@ -1,6 +1,6 @@
 // media.h -- Surrounding media
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __MEDIA_H__
-#define __MEDIA_H__
+#ifndef SNOGRAY_MEDIA_H
+#define SNOGRAY_MEDIA_H
 
 
 namespace snogray {
@@ -104,4 +104,4 @@ private:
 }
 
 
-#endif /* __MEDIA_H__ */
+#endif /* SNOGRAY_MEDIA_H */
