@@ -1,6 +1,6 @@
 // mesh.cc -- Mesh surface			-*- coding: utf-8 -*-
 //
-//  Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2005-2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -199,7 +199,7 @@ Mesh::add_vertices (const std::vector<scoord_t> &new_verts)
   for (unsigned v = base_vert; v < base_vert + num_new_verts; v++)
     {
       vertices[v]
-	= Pos (new_verts[nvi], new_verts[nvi + 1], new_verts[nvi + 2]);
+	= MPos (new_verts[nvi], new_verts[nvi + 1], new_verts[nvi + 2]);
       nvi += 3;
     }
 
@@ -260,7 +260,7 @@ Mesh::add_normals (const std::vector<sdist_t> &new_normals,
   for (unsigned ni = base_vert; ni < base_vert + num_new_normals; ni++)
     {
       vertex_normals[ni]
-	= Vec (new_normals[nni], new_normals[nni + 1], new_normals[nni + 2]);
+	= MVec (new_normals[nni], new_normals[nni + 1], new_normals[nni + 2]);
       nni += 3;
     }
 }
@@ -501,14 +501,14 @@ Mesh::Triangle::IsecInfo::make_intersect (const Media &media, RenderContext &con
 
   // Calculate du/ds, du/dt, dv/ds, and dv/dt.
   //
-  float du_den = e1.x * (e2.y + e2.z) - e2.x * (e1.y + e1.z);
-  float inv_du_den = du_den == 0 ? 0 : 1 / du_den;
-  float duds = (e2.y + e2.z) * inv_du_den;
-  float dudt = -e2.x * inv_du_den;
-  float dv_den = e2.x * (e1.y + e1.z) - e1.x * (e2.y + e2.z);
-  float inv_dv_den = dv_den == 0 ? 0 : 1 / dv_den;
-  float dvds = (e1.y + e1.z) * inv_dv_den;
-  float dvdt = -e1.x * inv_dv_den;
+  dist_t du_den = e1.x * (e2.y + e2.z) - e2.x * (e1.y + e1.z);
+  dist_t inv_du_den = du_den == 0 ? 0 : 1 / du_den;
+  dist_t duds = (e2.y + e2.z) * inv_du_den;
+  dist_t dudt = -e2.x * inv_du_den;
+  dist_t dv_den = e2.x * (e1.y + e1.z) - e1.x * (e2.y + e2.z);
+  dist_t inv_dv_den = dv_den == 0 ? 0 : 1 / dv_den;
+  dist_t dvds = (e1.y + e1.z) * inv_dv_den;
+  dist_t dvdt = -e1.x * inv_dv_den;
 
   // Calculate texture coordinate partial derivatives, in normal space.
   //
@@ -565,11 +565,6 @@ Mesh::Triangle::intersects (const Ray &ray, RenderContext &) const
 // probably considered opaque because it changes light direction as
 // well as transmitting it).
 //
-// [This interface is slight awkward for reasons of speed --
-// returning and checking for a boolean value for common cases is
-// significantly faster than, for instance, a simple "transmittance"
-// method, which requires handling Color values for all cases.]
-//
 bool
 Mesh::Triangle::occludes (const Ray &ray, const Medium &medium,
 			  Color &total_transmittance,
@@ -695,9 +690,9 @@ VertNormGroups::add_face (const Mesh::MVec &face_normal,
   // because it's the first normal added to it, or because the angle
   // between FACE_NORMAL and the group's normal is sufficiently small.
   //
-  dist_t dot_fg;
+  float cos_fg;
   if (group.num_faces == 0
-      || (dot_fg = dot (face_normal, group.normal) >= min_cos))
+      || (cos_fg = cos_angle (face_normal, group.normal) >= min_cos))
     //
     // It fits, add FACE_NORMAL to GROUP, and return VERTEX.
     {
@@ -706,7 +701,7 @@ VertNormGroups::add_face (const Mesh::MVec &face_normal,
       group.normal = group.normal_sum.unit ();
       return vertex;
     }
-  else if (dot_fg < 0)
+  else if (cos_fg < 0)
     {
       throw runtime_error ("Face orientation mismatch while smoothing mesh");
     }
@@ -789,7 +784,16 @@ Mesh::add_to_space (SpaceBuilder &space_builder) const
 	      << std::endl;
 
   for (unsigned i = 0; i < triangles.size(); i++)
-    triangles[i].add_to_space (space_builder);
+    {
+      const Triangle &tri = triangles[i];
+
+      // Degenerate triangles (those with a zero-length normal) can
+      // cause a crash during rendering, so only add non-degenerate
+      // triangles.
+      //
+      if (tri.raw_normal_unscaled().length_squared() > 0)
+	tri.add_to_space (space_builder);
+    }
 }
 
 // Recalculate this mesh's bounding box.
@@ -844,5 +848,75 @@ Mesh::transform (const Xform &xform)
   recalc_bbox ();
 }
 
+
+// Mesh intersection methods
+//
+// These are not normally called during rendering -- instead,
+// individual triangles in a mesh are added to acceleration
+// structures, and their intersection methods are called instead --
+// but are provided for completeness, and to make the Mesh class
+// concrete (Surface is an abstract class).
+
+
+// If this surface intersects RAY, change RAY's maximum bound (Ray::t1) to
+// reflect the point of intersection, and return a Surface::IsecInfo object
+// describing the intersection (which should be allocated using
+// placement-new with CONTEXT); otherwise return zero.
+//
+const Surface::IsecInfo *
+Mesh::intersect (Ray &ray, RenderContext &context) const
+{
+  const Surface::IsecInfo *closest = 0;
+
+  unsigned num_triangles = triangles.size();
+  for (unsigned t = 0; t < num_triangles; t++)
+    {
+      const Surface::IsecInfo *isec_info = triangles[t].intersect (ray, context);
+      if (isec_info)
+	closest = isec_info;
+    }
+
+  return closest;
+}
+
+// Return true if this surface intersects RAY.
+//
+bool
+Mesh::intersects (const Ray &ray, RenderContext &context) const
+{
+  unsigned num_triangles = triangles.size();
+  for (unsigned t = 0; t < num_triangles; t++)
+    if (triangles[t].intersects (ray, context))
+      return true;
+
+  return false;
+}
+
+// Return true if this surface completely occludes RAY.  If it does
+// not completely occlude RAY, then return false, and multiply
+// TOTAL_TRANSMITTANCE by the transmittance of the surface in medium
+// MEDIUM.
+//
+// Note that this method does not try to handle non-trivial forms of
+// transparency/translucency (for instance, a "glass" material is
+// probably considered opaque because it changes light direction as
+// well as transmitting it).
+//
+bool
+Mesh::occludes (const Ray &ray, const Medium &medium,
+			Color &total_transmittance,
+			RenderContext &context)
+  const
+{
+  unsigned num_triangles = triangles.size();
+
+  for (unsigned t = 0; t < num_triangles; t++)
+    if (triangles[t].occludes (ray, medium, total_transmittance, context))
+      return true;
+
+  return false;
+}
+
+
 
 // arch-tag: 3090c323-f2dd-48ef-b8fc-20ce5d687c66
