@@ -11,8 +11,8 @@
 //
 
 
-#ifndef __NUM_CORES_H__
-#define __NUM_CORES_H__
+#ifndef SNOGRAY_NUM_CORES_H
+#define SNOGRAY_NUM_CORES_H
 
 
 namespace snogray {
@@ -21,10 +21,10 @@ namespace snogray {
 // If the number of available CPU cores on this system can be
 // determined, return it, otherwise return DEFAULT_CORES.
 //
-extern int num_cores (int default_cores);
+extern int num_cores (int default_cores = 1);
 
 
 }
 
 
-#endif // __NUM_CORES_H__
+#endif // SNOGRAY_NUM_CORES_H
