@@ -1,6 +1,6 @@
 // random-boost.h -- Random number classes using boost::random
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __RANDOM_BOOST_H__
-#define __RANDOM_BOOST_H__
+#ifndef SNOGRAY_RANDOM_BOOST_H
+#define SNOGRAY_RANDOM_BOOST_H
 
 #include <boost/random.hpp>
 
@@ -41,4 +41,4 @@ private:
 
 }
 
-#endif // __RANDOM_BOOST_H__
+#endif // SNOGRAY_RANDOM_BOOST_H
