@@ -1,6 +1,6 @@
 // random-tr1.h -- Random number classes using C++0x TR1 std::random
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __RANDOM_TR1_H__
-#define __RANDOM_TR1_H__
+#ifndef SNOGRAY_RANDOM_TR1_H
+#define SNOGRAY_RANDOM_TR1_H
 
 #include <random>
 
@@ -43,4 +43,4 @@ private:
 
 }
 
-#endif // __RANDOM_TR1_H__
+#endif // SNOGRAY_RANDOM_TR1_H
