@@ -1,6 +1,6 @@
 // renderer.cc -- Output rendering object
 //
-//  Copyright (C) 2006, 2007, 2008, 2009, 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2006-2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -22,6 +22,7 @@
 #include "render-thread.h"
 #include "render-queue.h"
 #endif
+#include "float-excepts-guard.h"
 
 #include "render-mgr.h"
 
@@ -46,9 +47,23 @@ RenderMgr::RenderMgr (const GlobalRenderState &_global_state,
 //
 void
 RenderMgr::render (unsigned num_threads,
-		   RenderPattern &pattern, ImageOutput &output,
+		   RenderPattern &pattern,
+		   ImageSampledOutput &output,
 		   Progress &prog, RenderStats &stats)
 {
+  // Tell the progress indicator the bounds we will be using.
+  //
+  prog.set_start (pattern.position (pattern.begin ()));
+  prog.set_size (pattern.position (pattern.end ())
+		 - pattern.position (pattern.begin ()));
+
+  // Turn on floating-point exceptions during rendering if possible,
+  // to detect errors.
+  //
+  FloatExceptsGuard fe_guard (FE_DIVBYZERO|FE_INVALID);
+
+  // Render!
+  //
 #if USE_THREADS
   if (num_threads != 1)
     render_multi_threaded (num_threads, pattern, output, prog, stats);
@@ -66,7 +81,8 @@ RenderMgr::render (unsigned num_threads,
 // STATS will be updated with rendering statistics.
 //
 void
-RenderMgr::render_single_threaded (RenderPattern &pattern, ImageOutput &output,
+RenderMgr::render_single_threaded (RenderPattern &pattern,
+				   ImageSampledOutput &output,
 				   Progress &prog, RenderStats &stats)
 {
   Renderer renderer (global_state, camera, width, height);
@@ -107,7 +123,8 @@ RenderMgr::render_single_threaded (RenderPattern &pattern, ImageOutput &output,
 //
 void
 RenderMgr::render_multi_threaded (unsigned num_threads,
-				  RenderPattern &pattern, ImageOutput &output,
+				  RenderPattern &pattern,
+				  ImageSampledOutput &output,
 				  Progress &prog, RenderStats &stats)
 {
   RenderPattern::iterator pat_it = pattern.begin ();
@@ -240,7 +257,7 @@ RenderMgr::fill_packet (RenderPattern::iterator &pat_it,
 // Output results from PACKET to OUTPUT.
 //
 void
-RenderMgr::output_packet (RenderPacket &packet, ImageOutput &output)
+RenderMgr::output_packet (RenderPacket &packet, ImageSampledOutput &output)
 {
   for (std::vector<RenderPacket::Result>::iterator ri = packet.results.begin ();
        ri != packet.results.end (); ++ri)
