@@ -1,6 +1,6 @@
 // rusage.h -- Resource usage measurement
 //
-//  Copyright (C) 2005, 2007, 2011  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2005, 2007, 2011, 2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -15,20 +15,25 @@
 
 #include <sys/resource.h>
 
-#include "timeval.h"
 
 namespace snogray {
 
+
 struct Rusage : rusage
 {
   Rusage () { getrusage (RUSAGE_SELF, static_cast<struct rusage *>(this)); }
 
-  Timeval utime () const { return Timeval (ru_utime); }
-  Timeval stime () const { return Timeval (ru_stime); }
+  double utime () const
+  {
+    return double (ru_utime.tv_sec) + double (ru_utime.tv_usec) / 1e6;
+  }
+  double stime () const
+  {
+    return double (ru_stime.tv_sec) + double (ru_stime.tv_usec) / 1e6;
+  }
 };
 
+
 }
 
-#endif /* SNOGRAY_RUSAGE_H */
-
-// arch-tag: 7a4422b7-3908-44f2-9105-95b6905b6905
+#endif // SNOGRAY_RUSAGE_H
