@@ -31,13 +31,14 @@
 #include "camera.h"
 #include "light.h"
 #include "render-mgr.h"
-#include "recover.h"
+#include "recover-image.h"
 #include "image-input.h"
 #include "image-sampled-output-cmdline.h"
 #include "render-cmdline.h"
-#include "scene-def.h"
+#include "scene-cmdline.h"
 #include "camera-cmds.h"
 #include "render-stats.h"
+#include "load-lua.h"
 #include "octree.h"
 #include "pos-io.h"
 #include "vec-io.h"
@@ -188,7 +189,7 @@ static void
 usage (CmdLineParser &clp, ostream &os)
 {
   os << "Usage: " << clp.prog_name()
-     << " [OPTION...] SCENE_FILE... OUTPUT_IMAGE_FILE" << endl;
+     << " [OPTION...] SCENE_FILE [OUTPUT_IMAGE_FILE]" << endl;
 }
 
 static void
@@ -229,7 +230,7 @@ s "                               v           Set camera orientation to vertic"
 n
 s " Scene options:"
 n
-s SCENE_DEF_OPTIONS_HELP
+s SCENE_OPTIONS_HELP
 n
 s " Output image options:"
 n
@@ -290,7 +291,7 @@ int main (int argc, char *const *argv)
 #if USE_THREADS
     "j:"
 #endif
-    SCENE_DEF_SHORT_OPTIONS
+    SCENE_SHORT_OPTIONS
     RENDER_SHORT_OPTIONS
     IMAGE_SAMPLED_OUTPUT_SHORT_OPTIONS
     CMDLINEPARSER_GENERAL_SHORT_OPTIONS;
@@ -305,8 +306,10 @@ int main (int argc, char *const *argv)
   bool recover = false;
   TtyProgress::Verbosity verbosity = TtyProgress::CHATTY;
   bool progress_set = false;
-  ValTable output_params, render_params;
-  SceneDef scene_def;
+  ValTable params;
+  ValTable &scene_params = params.writable_subtable ("scene");
+  ValTable &output_params = params.writable_subtable ("output");
+  ValTable &render_params = params.writable_subtable ("render");
   std::string camera_cmds;	// User commands for the camera
 
 
@@ -357,7 +360,7 @@ int main (int argc, char *const *argv)
 
 	// Scene options
 	//
-	SCENE_DEF_OPTION_CASES (clp, scene_def);
+	SCENE_OPTION_CASES (clp, scene_params);
 
 	// Image options
 	//
@@ -368,20 +371,23 @@ int main (int argc, char *const *argv)
 	CMDLINEPARSER_GENERAL_OPTION_CASES (clp);
       }
 
-  if (clp.num_remaining_args() < 2)
+  // There should be one scene file, and optionally one output file
+  //
+  if (clp.num_remaining_args() < 1 || clp.num_remaining_args() > 2)
     {
       usage (clp, cerr);
       exit (1);
     }
 
-  // Parse scene filename
+  // Scene file name
   //
-  CMDLINEPARSER_CATCH
-    (clp, scene_def.parse (clp, clp.num_remaining_args() - 1));
+  std::string scene_file = clp.get_arg ();
 
-  // Output filename
+  // Output filename; this is optional, as the scene file can actually
+  // specify an output filename itself.
   //
-  output_params.set ("filename", clp.get_arg ());
+  if (clp.num_remaining_args () == 1)
+    output_params.set ("filename", clp.get_arg ());
 
 
   // Start of "overall elapsed" time
@@ -413,22 +419,13 @@ int main (int argc, char *const *argv)
   if (width && height)
     camera.set_aspect_ratio (float (width) / float (height));
 
-  // Read in the scene/camera definitions.  We copy our parameter
-  // tables into SCENE_DEF's parameter table with appropriate
-  // prefixes, so that they're available for scene-loaders to
-  // examine/change.
+  // Handle command-line scene parameters.
   //
-  scene_def.params.import (render_params, "render.");
-  scene_def.params.import (output_params, "output.");
-  CMDLINEPARSER_CATCH (clp, scene_def.load (scene, camera));
+  process_scene_params (scene_params, scene);
 
-  // Now rewrite our parameter tables appropriately-prefixed
-  // parameters from SCENE_DEF.  As we earlier stored them, that means
-  // they'll be the same unless the scene-loader changed something.
+  // Read in the scene/camera definitions.
   //
-  render_params = scene_def.params.filter_by_prefix ("render.");
-  output_params = scene_def.params.filter_by_prefix ("output.");
-
+  load_lua_file (scene_file, scene, camera, params);
 
   // Do post-load scene setup (nothing can be added to scene after this).
   //
@@ -458,6 +455,11 @@ int main (int argc, char *const *argv)
   //
   std::string file_name = output_params.get_string ("filename");
 
+  // An output file must be specified either on the command-line, or
+  // by the scene file.
+  //
+  if (file_name.empty ())
+    clp.err ("no output file specified");
 
   // Set our drawing limits based on the scene size
   //
@@ -470,27 +472,26 @@ int main (int argc, char *const *argv)
 
   // If possible, try to recover a previously aborted render.
   //
-  ImageInput *recover_input = 0;
+  std::string recover_backup;
   if (file_exists (file_name))
     {
       if (recover)
-	//
-	// Recover a previous aborted render
-	try
-	  {
-	    recover_input = new ImageInput (file_name);
+	{
+	  // Recover a previous aborted render
+	  try
+	    {
+	      recover_backup
+		= rename_to_backup_file (file_name, RECOVER_BACKUP_LIMIT);
 
-	    string recover_backup
-	      = rename_to_backup_file (file_name, RECOVER_BACKUP_LIMIT);
-
-	    if (! quiet)
-	      cout << "* recover: " << file_name
-		   << ": Backup in " << recover_backup << endl;
-	  }
-	catch (runtime_error &err)
-	  {
-	    clp.err (err.what ());
-	  }
+	      if (! quiet)
+		cout << "* recover: " << file_name
+		     << ": Backup in " << recover_backup << endl;
+	    }
+	  catch (runtime_error &err)
+	    {
+	      clp.err (err.what ());
+	    }
+	}
       else
 	{
 	  cerr << clp.err_pfx() << file_name << ": Output file already exists"
@@ -506,15 +507,15 @@ int main (int argc, char *const *argv)
   // Set the base-coordinates of the "output sample space" to LIMIT_X, LIMIT_Y.
   //
   if (limit_x != 0)
-    output_params.set ("sample-base-x", limit_x);
+    output_params.set ("sample_base_x", limit_x);
   if (limit_y != 0)
-    output_params.set ("sample-base-y", limit_y);
+    output_params.set ("sample_base_y", limit_y);
 
   // If the scene has a non-default background alpha set, then make sure
   // there's an alpha-channel in the output image.
   //
-  if (render_params.get_float ("background-alpha", 1) != 1)
-    output_params.set ("alpha-channel", true);
+  if (render_params.get_float ("background_alpha", 1) != 1)
+    output_params.set ("alpha_channel", true);
 
   // Create output image.  The size of what we output is the same as the
   // limit (which defaults to, but is not the same as the nominal output
@@ -527,7 +528,7 @@ int main (int argc, char *const *argv)
   ImageSampledOutput output (file_name, limit_width, limit_height,
 			     output_params);
 
-  if (output_params.get_bool ("alpha-channel,alpha")
+  if (output_params.get_bool ("alpha_channel,alpha")
       && !output.has_alpha_channel())
     {
       std::cerr << clp.err_pfx() << file_name
@@ -536,10 +537,10 @@ int main (int argc, char *const *argv)
       return 1;
     }
 
-  if (recover_input)
+  if (! recover_backup.empty ())
     {
-      unsigned num_rows_recovered = recover_image (recover_input, output);
-      recover_input = 0;
+      unsigned num_rows_recovered
+	= recover_image (recover_backup, file_name, output_params, output);
 
       if (! quiet)
 	cout << "* recover: " << file_name
