@@ -1,6 +1,6 @@
 // spheremap.h -- Texture wrapped around a sphere
 //
-//  Copyright (C) 2006, 2007, 2008, 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2006-2008, 2010-2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __SPHEREMAP_H__
-#define __SPHEREMAP_H__
+#ifndef SNOGRAY_SPHEREMAP_H
+#define SNOGRAY_SPHEREMAP_H
 
 #include "tex.h"
 #include "snogmath.h"
@@ -36,19 +36,11 @@ struct LatLongMapping
 {
   static UV map (const Vec &dir)
   {
-    return y_axis_latlong (dir);
+    return z_axis_latlong (dir);
   }
   static Vec map (const UV &uv)
   {
-    return y_axis_latlong_to_vec (uv);
-  }
-
-  // Returns the area on the sphere corresponding to a one-unit area at
-  // location UV in the texture.
-  //
-  static float sphere_area (UV uv)
-  {
-    return cos (uv.v * PIf - PIf/2);
+    return z_axis_latlong_to_vec (uv);
   }
 };
 
@@ -59,7 +51,7 @@ struct MercatorMapping
 {
   static UV map (const Vec &dir) const
   {
-    return UV (clamp01 ((dir.y_axis_longitude () + PIf) * INV_PIf / 2),
+    return UV (clamp01 ((z_axis_longitude (dir) + PIf) * INV_PIf / 2),
 	       clamp01 ((dir.y + 1) / 2);
   }
 
@@ -108,7 +100,7 @@ struct DebevecMapping
   static Vec map (const UV &uv)
   {
     dist_t u = uv.u * 2 - 1, v = uv.v * 2 - 1;
-    dist_t theta = atan2 (v, u), phi = PI * sqrt (u * u + v * v);
+    dist_t theta = atan2 (v, u), phi = dist_t (PI) * sqrt (u * u + v * v);
     dist_t sin_phi = sin (phi);
     return Vec (sin_phi * sin (theta), cos (phi), sin_phi * cos (theta));
   }
@@ -135,7 +127,7 @@ struct MirrorBallMapping
   static Vec map (const UV &uv)
   {
     dist_t u = uv.u * 2 - 1, v = uv.v * 2 - 1;
-    dist_t theta = atan2 (v, u), phi = PI * sqrt (u * u + v * v);
+    dist_t theta = atan2 (v, u), phi = dist_t (PI) * sqrt (u * u + v * v);
     dist_t sin_phi = sin (phi);
     return Vec (sin_phi * sin (theta), cos (phi), sin_phi * cos (theta));
   }
@@ -195,7 +187,7 @@ Ref<Image> Spheremap<LatLongMapping>::light_map () const;
 
 }
 
-#endif // __SPHEREMAP_H__
+#endif // SNOGRAY_SPHEREMAP_H
 
 
 // arch-tag: 13f3c349-9a3e-4337-ba26-cf083997542f
