@@ -1,6 +1,6 @@
 // tuple-adaptor.h -- Converter between types and tuples
 //
-//  Copyright (C) 2008  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2008, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __TUPLE_ADAPTOR_H__
-#define __TUPLE_ADAPTOR_H__
+#ifndef SNOGRAY_TUPLE_ADAPTOR_H
+#define SNOGRAY_TUPLE_ADAPTOR_H
 
 
 namespace snogray {
@@ -43,4 +43,4 @@ private:
 
 }
 
-#endif // __TUPLE_ADAPTOR_H__
+#endif // SNOGRAY_TUPLE_ADAPTOR_H
