@@ -10,6 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
+#include <ostream>
+
 #include "nice-io.h"
 
 #include "vec-io.h"
@@ -17,12 +19,12 @@
 std::ostream&
 snogray::operator<< (std::ostream &os, const Vec &vec)
 {
-  os << "vec<";
+  os << "vec{";
   output_nicely (os, vec.x);
   os << ", ";
   output_nicely (os, vec.y);
   os << ", ";
   output_nicely (os, vec.z);
-  os << ">";
+  os << "}";
   return os;
 }
