@@ -1,6 +1,6 @@
 // xform-tex.h -- Texture coordinate transform
 //
-//  Copyright (C) 2008, 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2008, 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __XFORM_TEX_H__
-#define __XFORM_TEX_H__
+#ifndef SNOGRAY_XFORM_TEX_H
+#define SNOGRAY_XFORM_TEX_H
 
 #include "tex.h"
 
@@ -53,4 +53,4 @@ public:
 
 }
 
-#endif // __XFORM_TEX_H__
+#endif // SNOGRAY_XFORM_TEX_H
